==> jc-1.4.0.tar.gz: ppg/atoms/PrecedenceModifier.h <==
// public class ppg.atoms.PrecedenceModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 8f58e9ce2936b12d ppg_atoms_PrecedenceModifier

// header file dependencies
// @dep_header ppg_atoms_GrammarPart

#include "ppg/atoms/GrammarPart.h"

#ifndef _JC_ppg_atoms_PrecedenceModifier_H_
#define _JC_ppg_atoms_PrecedenceModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_atoms_PrecedenceModifier$sub_refs	_jc_ppg_atoms_PrecedenceModifier$sub_refs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$sub_nonrefs	_jc_ppg_atoms_PrecedenceModifier$sub_nonrefs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$refs	_jc_ppg_atoms_PrecedenceModifier$refs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$nonrefs	_jc_ppg_atoms_PrecedenceModifier$nonrefs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$object	_jc_ppg_atoms_PrecedenceModifier$object;

typedef const struct _jc_ppg_atoms_PrecedenceModifier$vmethods	_jc_ppg_atoms_PrecedenceModifier$vmethods;
typedef const struct _jc_ppg_atoms_PrecedenceModifier$vtable	_jc_ppg_atoms_PrecedenceModifier$vtable;
typedef const struct _jc_ppg_atoms_PrecedenceModifier$vtype	_jc_ppg_atoms_PrecedenceModifier$vtype;

// Constructors
extern void _jc_ppg_atoms_PrecedenceModifier$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_PrecedenceModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_PrecedenceModifier$method$getTerminalName$cd23b74c581383d5(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_PrecedenceModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *);
extern void _jc_ppg_atoms_PrecedenceModifier$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *, struct _jc_ppg_util_CodeWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$getTerminalName$cd23b74c581383d5;
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_atoms_PrecedenceModifier$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *);
	struct _jc_java_lang_String$object	*(*getTerminalName$cd23b74c581383d5)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *);
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *, struct _jc_ppg_util_CodeWriter$object *);
};

// Vtable
struct _jc_ppg_atoms_PrecedenceModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_PrecedenceModifier$vmethods	ppg_atoms_PrecedenceModifier;
};

// Vtype
struct _jc_ppg_atoms_PrecedenceModifier$vtype {
	_jc_type			type;
	_jc_ppg_atoms_PrecedenceModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_PrecedenceModifier$sub_refs {
	struct _jc_java_lang_String$object	*terminalName;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_PrecedenceModifier$refs {
    _jc_ppg_atoms_PrecedenceModifier$sub_refs	ppg_atoms_PrecedenceModifier;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_PrecedenceModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_PrecedenceModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_PrecedenceModifier$sub_nonrefs	ppg_atoms_PrecedenceModifier;
};

// Object instance structure
struct _jc_ppg_atoms_PrecedenceModifier$object {
	_jc_ppg_atoms_PrecedenceModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_PrecedenceModifier$vtype	*vtype;
	_jc_ppg_atoms_PrecedenceModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_PrecedenceModifier$vtype _jc_ppg_atoms_PrecedenceModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_PrecedenceModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_PrecedenceModifier$class_object;

#endif	/* _JC_ppg_atoms_PrecedenceModifier_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/PrecedenceModifier.h <==
// public class ppg.atoms.PrecedenceModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 8f58e9ce2936b12d ppg_atoms_PrecedenceModifier

// header file dependencies
// @dep_header ppg_atoms_GrammarPart

#include "ppg/atoms/GrammarPart.h"

#ifndef _JC_ppg_atoms_PrecedenceModifier_H_
#define _JC_ppg_atoms_PrecedenceModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_atoms_PrecedenceModifier$sub_refs	_jc_ppg_atoms_PrecedenceModifier$sub_refs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$sub_nonrefs	_jc_ppg_atoms_PrecedenceModifier$sub_nonrefs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$refs	_jc_ppg_atoms_PrecedenceModifier$refs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$nonrefs	_jc_ppg_atoms_PrecedenceModifier$nonrefs;
typedef struct _jc_ppg_atoms_PrecedenceModifier$object	_jc_ppg_atoms_PrecedenceModifier$object;

typedef const struct _jc_ppg_atoms_PrecedenceModifier$vmethods	_jc_ppg_atoms_PrecedenceModifier$vmethods;
typedef const struct _jc_ppg_atoms_PrecedenceModifier$vtable	_jc_ppg_atoms_PrecedenceModifier$vtable;
typedef const struct _jc_ppg_atoms_PrecedenceModifier$vtype	_jc_ppg_atoms_PrecedenceModifier$vtype;

// Constructors
extern void _jc_ppg_atoms_PrecedenceModifier$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_PrecedenceModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_PrecedenceModifier$method$getTerminalName$cd23b74c581383d5(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_PrecedenceModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_atoms_PrecedenceModifier$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$getTerminalName$cd23b74c581383d5;
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_ppg_atoms_PrecedenceModifier$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_atoms_PrecedenceModifier$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getTerminalName$cd23b74c581383d5)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *) _JC_JCNI_ATTR;
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_atoms_PrecedenceModifier$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_PrecedenceModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_PrecedenceModifier$vmethods	ppg_atoms_PrecedenceModifier;
};

// Vtype
struct _jc_ppg_atoms_PrecedenceModifier$vtype {
	_jc_type			type;
	_jc_ppg_atoms_PrecedenceModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_PrecedenceModifier$sub_refs {
	struct _jc_java_lang_String$object	*terminalName;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_PrecedenceModifier$refs {
    _jc_ppg_atoms_PrecedenceModifier$sub_refs	ppg_atoms_PrecedenceModifier;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_PrecedenceModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_PrecedenceModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_PrecedenceModifier$sub_nonrefs	ppg_atoms_PrecedenceModifier;
};

// Object instance structure
struct _jc_ppg_atoms_PrecedenceModifier$object {
	_jc_ppg_atoms_PrecedenceModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_PrecedenceModifier$vtype	*vtype;
	_jc_ppg_atoms_PrecedenceModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_PrecedenceModifier$vtype _jc_ppg_atoms_PrecedenceModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_PrecedenceModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_PrecedenceModifier$class_object;

#endif	/* _JC_ppg_atoms_PrecedenceModifier_H_ */
